An in-RAM chat memory that a test can read back. Port of
wabot-ts/src/testing/TestChatMemory.ts.
Structs
- Test
Chat Memory - Like
InMemoryChatMemory, but it exposes the whole item list.
An in-RAM chat memory that a test can read back. Port of
wabot-ts/src/testing/TestChatMemory.ts.
InMemoryChatMemory, but it exposes the whole item list.